---
title: <span class="badge builder"></span> ElasticsearchLogsSettings
---
# <span class="badge builder"></span> ElasticsearchLogsSettings

## Constructor

```python
ElasticsearchLogsSettings()
```
## Methods

### <span class="badge object-method"></span> build

Builds the object.

```python
def build() -> elasticsearch.ElasticsearchLogsSettings
```

### <span class="badge object-method"></span> limit

```python
def limit(limit: str) -> typing.Self
```

## See also

 * <span class="badge object-type-class"></span> [ElasticsearchLogsSettings](./object-ElasticsearchLogsSettings.md)
